import javax.microedition.lcdui.*;

public class SettingsForm extends Form implements CommandListener { 
    Displayable  parent;
    ReaderCanvas canvas;
    ChoiceGroup  font;
    ChoiceGroup  slider;
    ChoiceGroup  info;
    ChoiceGroup  background;
    Gauge        overlap;

    static final int MAX_OVERLAP = 4;

    static final int SMALL_FONT  = 0;
    static final int MEDIUM_FONT = 1;
    static final int LARGE_FONT  = 2;

    static final int SLIDER_HORIZONTAL = 1;
    static final int SLIDER_VERTICAL   = 2;

    static final int SHOW_CLOCK = 4;
    static final int INVERSE = 8;

    static String[] fontName = {
        "small",
        "medium",
        "large",
        "custom"
    };
          
    static String[] sliderType = {
        Locale.HORIZONTAL,
        Locale.VERTICAL
    };

    static String[] backgroundType = {
        Locale.WHITE,
        Locale.BLACK
    };
          
    static String[] infoType = {
        Locale.CLOCK
    };
          
    SettingsForm(ReaderCanvas canvas, Displayable parent) { 
        super(Locale.SETTINGS);        
        this.canvas = canvas;
        this.parent = parent;
        font = new ChoiceGroup(Locale.FONT, 
                               Choice.EXCLUSIVE,
                               fontName,
                               null);
        font.setSelectedIndex(canvas.reader.font, true);
        slider = new ChoiceGroup(Locale.SLIDER, 
                                 Choice.MULTIPLE,
                                 sliderType,
                                 null);
        slider.setSelectedFlags(new boolean[] { 
                                    (canvas.reader.flags & SLIDER_HORIZONTAL) != 0,
                                    (canvas.reader.flags & SLIDER_VERTICAL) != 0
                                });
        info = new ChoiceGroup(Locale.INFO, 
                               Choice.MULTIPLE,
                               infoType,
                               null);
        info.setSelectedFlags(new boolean[] { 
                              (canvas.reader.flags & SHOW_CLOCK) != 0
                              });
        background = new ChoiceGroup(Locale.BACKGROUND, 
                                     Choice.EXCLUSIVE,
                                     backgroundType,
                                     null);
        background.setSelectedIndex((canvas.reader.flags & INVERSE) == 0 ? 0 : 1, true);
                                                
        overlap = new Gauge(Locale.OVERLAP, true, MAX_OVERLAP, canvas.reader.overlap); 
        append(font);
        append(overlap);
        append(slider);
        append(info);
        append(background);
        addCommand(BookReader.SAVE_CMD);
        addCommand(BookReader.BACK_CMD);
        setCommandListener(this);
        Display.getDisplay(canvas.reader).setCurrent(this);
    }
    
    public void commandAction(Command c, Displayable d) 
    {
        if (c == BookReader.SAVE_CMD) { 
            canvas.reader.font = font.getSelectedIndex();
            canvas.reader.overlap = overlap.getValue();
            canvas.reader.flags = 0;
            boolean[] flags = new boolean[sliderType.length];
            slider.getSelectedFlags(flags);
            if (flags[0]) { 
                canvas.reader.flags |= SLIDER_HORIZONTAL;
            }
            if (flags[1]) { 
                canvas.reader.flags |= SLIDER_VERTICAL;
            }
            flags = new boolean[infoType.length];
            info.getSelectedFlags(flags);
            if (flags[0]) {                 
                canvas.reader.flags |= SHOW_CLOCK;
            }
            flags = new boolean[backgroundType.length];
            background.getSelectedFlags(flags);
            if (flags[1] && canvas.reader.font <= LARGE_FONT) { 
                canvas.reader.flags |= INVERSE;
            }
            canvas.initialized = false;
        }                
        Display.getDisplay(canvas.reader).setCurrent(parent);
    }
}
           

   